@@ -1,15 +1,15 @@
 __name__ = "orix"
-__version__ = "0.8.2"
+__version__ = "0.9.0.post0"
 __author__ = "orix developers"
 __author_email__ = "pyxem.team@gmail.com"
-__description__ = "orix is an open-source python library for handling crystal orientation mapping data."
-# Initial committer first, then sorted by line contributions
+__description__ = "orix is an open-source Python library for handling crystal orientation mapping data."
+# Sorted by line contributions (ideally excluding lines in notebook files)
 __credits__ = [
-    "Ben Martineau",
     "Håkon Wiik Ånes",
+    "Ben Martineau",
     "Phillip Crout",
-    "Duncan Johnstone",
     "Paddy Harrison",
+    "Duncan Johnstone",
     "Niels Cautaerts",
     "Simon Høgås",
 ]
