@@ -46,21 +46,27 @@ class deprecated:
     <https://github.com/matplotlib/matplotlib/blob/master/lib/matplotlib/_api/deprecation.py#L122>`_.
     """
 
-    def __init__(self, since, alternative=None, removal=None, object_type="function"):
+    def __init__(
+        self,
+        since,
+        removal=None,
+        object_type="function",
+        alternative=None,
+    ):
         """Visible deprecation warning.
 
         Parameters
         ----------
         since : str, int or float
             The release at which this API became deprecated.
-        alternative : str, optional
-            An alternative API that the user may use in place of the
-            deprecated API.
         removal : str, int or float, optional
             The expected removal version.
         object_type : str, optional
-            Type of the deprecated object, either "function" or
-            "property".
+            Type of the deprecated object, either "function" (default)
+            or "property".
+        alternative : str, optional
+            An alternative API that the user may use in place of the
+            deprecated API.
         """
         self.since = since
         self.alternative = alternative
@@ -69,13 +75,13 @@ class deprecated:
 
     def __call__(self, func):
         # Wrap function or property to raise warning when called, and
-        # add warning to docstring
-        if self.object_type.lower() != "function":
-            object_type = "Property"
-            parentheses = ""
-        else:
-            object_type = "Function"
+        # add warning to docstring if function or property is deprecated
+
+        object_type = self.object_type.lower()
+        if object_type == "function":
             parentheses = "()"
+        else:
+            parentheses = ""
         if self.alternative is not None:
             alt_msg = f" Use `{self.alternative}{parentheses}` instead."
         else:
@@ -85,7 +91,7 @@ class deprecated:
         else:
             rm_msg = ""
         msg = (
-            f"{object_type} `{func.__name__}{parentheses}` is deprecated"
+            f"{object_type.capitalize()} `{func.__name__}{parentheses}` is deprecated"
             f"{rm_msg}.{alt_msg}"
         )
 
@@ -115,3 +121,45 @@ class deprecated:
         wrapped.__doc__ = new_doc
 
         return wrapped
+
+
+class deprecated_argument:
+    """Decorator to remove an argument from a function or method's
+    signature.
+
+    Adopted from
+    `scikit-image
+    <https://github.com/scikit-image/scikit-image/blob/main/skimage/_shared/utils.py#L115>`_.
+    """
+
+    def __init__(self, name, since, removal, alternative=None):
+        self.name = name
+        self.since = since
+        self.removal = removal
+        self.alternative = alternative
+
+    def __call__(self, func):
+        @functools.wraps(func)
+        def wrapped(*args, **kwargs):
+            if self.name in kwargs.keys():
+                msg = (
+                    f"Argument `{self.name}` is deprecated and will be removed in "
+                    f"version {self.removal}. To avoid this warning, please do not use "
+                    f"`{self.name}`. "
+                )
+                if self.alternative is not None:
+                    msg += f"Use `{self.alternative}` instead. "
+                msg += f"See the documentation of `{func.__name__}()` for more details."
+                warnings.simplefilter(
+                    action="always", category=np.VisibleDeprecationWarning
+                )
+                func_code = func.__code__
+                warnings.warn_explicit(
+                    message=msg,
+                    category=np.VisibleDeprecationWarning,
+                    filename=func_code.co_filename,
+                    lineno=func_code.co_firstlineno + 1,
+                )
+            return func(*args, **kwargs)
+
+        return wrapped
