@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018-2021 the orix developers
+# Copyright 2018-2022 the orix developers
 #
 # This file is part of orix.
 #
@@ -28,7 +28,7 @@ import numpy as np
 
 from orix.crystal_map import CrystalMap, Phase, PhaseList
 from orix.io.plugins._h5ebsd import H5ebsdFile
-from orix.quaternion.rotation import Rotation
+from orix.quaternion import Rotation
 
 
 __all__ = ["file_reader"]
