@@ -49,8 +49,7 @@ from tqdm import tqdm
 
 from orix.quaternion.orientation_region import OrientationRegion
 from orix.quaternion.rotation import Rotation
-from orix.quaternion.symmetry import C1, Symmetry
-from orix.scalar import Scalar
+from orix.quaternion.symmetry import C1, Symmetry, _get_unique_symmetry_elements
 from orix.vector import AxAngle
 from orix._util import deprecated
 
@@ -101,7 +100,7 @@ def _distance(misorientation, verbose, split_size=100):
             # This works through all the identity rotations
             for s_2_1, s_2_2 in icombinations(S_2, 2):
                 m = s_2_1 * mis2orientation * s_2_2
-                angle = m.angle.data.min(axis=axis)
+                angle = m.angle.min(axis=axis)
                 distance[index_slice_a, index_slice_b] = np.minimum(
                     distance[index_slice_a, index_slice_b], angle
                 )
@@ -146,6 +145,17 @@ class Misorientation(Rotation):
         m._symmetry = self._symmetry
         return m
 
+    def __eq__(self, other):
+        v1 = super().__eq__(other)
+        if not v1:
+            return v1
+        else:
+            # check symmetries are also equivalent
+            v2 = []
+            for sym_s, sym_o in zip(self._symmetry, other._symmetry):
+                v2.append(sym_s == sym_o)
+            return all(v2)
+
     def reshape(self, *shape):
         m = super().reshape(*shape)
         m._symmetry = self._symmetry
@@ -187,40 +197,6 @@ class Misorientation(Rotation):
         equivalent = Gr.outer(orientations.outer(Gl))
         return self.__class__(equivalent).flatten()
 
-    @deprecated(
-        since="0.8",
-        alternative="orix.quaternion.Misorientation.map_into_symmetry_reduced_zone",
-        removal="0.9",
-    )
-    def set_symmetry(self, Gl, Gr, verbose=False):
-        """Assign symmetries to this misorientation.
-
-        Computes equivalent transformations which have the smallest
-        angle of rotation and assigns these in-place.
-
-        Parameters
-        ----------
-        Gl, Gr : Symmetry
-
-        Returns
-        -------
-        Misorientation
-            A new misorientation object with the assigned symmetry.
-
-        Examples
-        --------
-        >>> from orix.quaternion.symmetry import C4, C2
-        >>> data = np.array([[0.5, 0.5, 0.5, 0.5], [0, 1, 0, 0]])
-        >>> m = Misorientation(data).set_symmetry(C4, C2)
-        >>> m
-        Misorientation (2,) 4, 2
-        [[-0.7071  0.7071  0.      0.    ]
-        [ 0.      1.      0.      0.    ]]
-        """
-        misori = self.__class__(self.data)
-        misori.symmetry = (Gl, Gr)
-        return misori.map_into_symmetry_reduced_zone()
-
     def map_into_symmetry_reduced_zone(self, verbose=False):
         """Computes equivalent transformations which have the smallest
         angle of rotation and return these as a new Misorientation object.
@@ -258,6 +234,11 @@ class Misorientation(Rotation):
         o_inside._symmetry = (Gl, Gr)
         return o_inside
 
+    @deprecated(
+        since="0.9",
+        alternative="orix.quaternion.Misorientation.get_distance_matrix",
+        removal="0.10",
+    )
     def distance(self, verbose=False, split_size=100):
         """Symmetry reduced distance.
 
@@ -399,6 +380,94 @@ class Misorientation(Rotation):
         if return_figure:
             return figure
 
+    def get_distance_matrix(self, chunk_size=20, progressbar=True):
+        r"""The symmetry reduced smallest angle of rotation transforming
+        every misorientation in this instance to every other
+        misorientation :cite:`johnstone2020density`.
+
+        This is an alternative implementation of
+        :meth:`~orix.quaternion.Misorientation.distance` for
+        a single :class:`Misorientation` instance, using :mod:`dask`.
+
+        Parameters
+        ----------
+        chunk_size : int, optional
+            Number of misorientations per axis to include in each
+            iteration of the computation. Default is 20.
+        progressbar : bool, optional
+            Whether to show a progressbar during computation. Default is
+            True.
+
+        Returns
+        -------
+        numpy.ndarray
+
+        Notes
+        -----
+        Given two misorientations :math:`m_i` and :math:`m_j` with the
+        same two symmetry groups, the smallest angle is considered as
+        the geodesic distance
+
+        .. math::
+
+            d(m_i, m_j) = \arccos(2(m_i \cdot m_j)^2 - 1),
+
+        where :math:`(m_i \cdot m_j)` is the highest dot product
+        between symmetrically equivalent misorientations to
+        :math:`m_{i,j}`, given by
+
+        .. math::
+
+            \max_{s_k \in S_k} s_k m_i s_l s_k m_j^{-1} s_l,
+
+        where :math:`s_k \in S_k` and :math:`s_l \in S_l`, with
+        :math:`S_k` and :math:`S_l` being the two symmetry groups.
+
+        Examples
+        --------
+        >>> import numpy as np
+        >>> from orix.quaternion import Misorientation, symmetry
+        >>> m = Misorientation.from_axes_angles([1, 0, 0], [0, np.pi/2])
+        >>> m.symmetry = (symmetry.D6, symmetry.D6)
+        >>> d = m.get_distance_matrix()  # doctest: +SKIP
+        >>> d
+        [[0.         1.57079633]
+         [1.57079633 0.        ]]
+        """
+        # Reduce symmetry operations to the unique ones
+        symmetry = _get_unique_symmetry_elements(*self.symmetry)
+
+        # Perform "s_k m_i s_l s_k m_j" (see Notes)
+        misorientation1 = symmetry.outer(self).outer(symmetry)
+        misorientation2 = misorientation1._outer_dask(~self, chunk_size=chunk_size)
+
+        # Perform last outer product and reduce to all dot products at
+        # the same time
+        warnings.filterwarnings("ignore", category=da.PerformanceWarning)
+        str1 = "abcdefghijklmnopqrstuvwxy"[: misorientation2.ndim]
+        str2 = "z" + str1[-1]  # Last axis has shape (4,)
+        sum_over = f"{str1},{str2}->{str1[:-1] + str2[0]}"
+        all_dot_products = da.einsum(sum_over, misorientation2, symmetry.data)
+
+        # Get highest dot product
+        axes = (0, self.ndim + 1, 2 * self.ndim + 2)
+        dot_products = da.max(abs(all_dot_products), axis=axes)
+
+        # Round because some dot products are slightly above 1
+        dot_products = da.round(dot_products, 12)
+
+        # Calculate disorientation angles
+        angles_dask = da.arccos(2 * dot_products**2 - 1)
+        angles_dask = da.nan_to_num(angles_dask)
+        angles = np.zeros(angles_dask.shape)
+        if progressbar:
+            with ProgressBar():
+                da.store(sources=angles_dask, targets=angles)
+        else:
+            da.store(sources=angles_dask, targets=angles)
+
+        return angles
+
 
 class Orientation(Misorientation):
     """Orientations represent misorientations away from a reference of
@@ -450,10 +519,9 @@ class Orientation(Misorientation):
             return misorientation.map_into_symmetry_reduced_zone()
         return NotImplemented
 
+    # TODO: Remove use of **kwargs in 1.0
     @classmethod
-    def from_euler(
-        cls, euler, symmetry=None, convention="bunge", direction="crystal2lab"
-    ):
+    def from_euler(cls, euler, symmetry=None, direction="lab2crystal", **kwargs):
         """Creates orientation(s) from an array of Euler angles.
 
         Parameters
@@ -463,12 +531,12 @@ class Orientation(Misorientation):
         symmetry : Symmetry, optional
             Symmetry of orientation(s). If None (default), no symmetry
             is set.
-        convention : str
-            Only 'bunge' is currently supported for new data
         direction : str
-            'lab2crystal' or 'crystal2lab'
+            "lab2crystal" (default) or "crystal2lab". "lab2crystal"
+            is the Bunge convention. If "MTEX" is provided then the
+            direction is "crystal2lab".
         """
-        o = super().from_euler(euler=euler, convention=convention, direction=direction)
+        o = super().from_euler(euler=euler, direction=direction, **kwargs)
         if symmetry:
             o.symmetry = symmetry
         return o
@@ -553,53 +621,20 @@ class Orientation(Misorientation):
 
         Returns
         -------
-        Scalar
+        numpy.ndarray
+
+        See also
+        --------
+        angle_with_outer
         """
-        dot_products = self.unit.dot(other.unit).data
+        dot_products = self.unit.dot(other.unit)
         angles = np.nan_to_num(np.arccos(2 * dot_products**2 - 1))
-        return Scalar(angles)
+        return angles
 
-    def dot(self, other):
-        """Symmetry reduced dot product of orientations in this instance
-        to orientations in another instance, returned as
-        :class:`~orix.scalar.Scalar`.
-
-        See Also
-        --------
-        dot_outer
-        """
-        symmetry = self.symmetry.outer(other.symmetry).unique()
-        misorientation = other * ~self
-        all_dot_products = Rotation(misorientation).dot_outer(symmetry).data
-        highest_dot_product = np.max(all_dot_products, axis=-1)
-        return Scalar(highest_dot_product)
-
-    def dot_outer(self, other):
-        """Symmetry reduced dot product of every orientation in this
-        instance to every orientation in another instance, returned as
-        :class:`~orix.scalar.Scalar`.
-
-        See Also
-        --------
-        dot
-        """
-        symmetry = self.symmetry.outer(other.symmetry).unique()
-        misorientation = other.outer(~self)
-        all_dot_products = Rotation(misorientation).dot_outer(symmetry).data
-        highest_dot_product = np.max(all_dot_products, axis=-1)
-        return Scalar(highest_dot_product)
-
-    @deprecated(
-        since="0.7",
-        alternative="orix.quaternion.Orientation.get_distance_matrix",
-        removal="0.8",
-    )
-    def distance(self, verbose=False, split_size=100):
-        return super().distance(verbose=verbose, split_size=split_size)
-
-    def get_distance_matrix(self, lazy=False, chunk_size=20, progressbar=True):
+    def angle_with_outer(self, other, lazy=False, chunk_size=20, progressbar=True):
         r"""The symmetry reduced smallest angle of rotation transforming
-        each orientation in this instance to every other orientation.
+        every orientation in this instance to every orientation in
+        another instance.
 
         This is an alternative implementation of
         :meth:`~orix.quaternion.Misorientation.distance` for
@@ -620,7 +655,11 @@ class Orientation(Misorientation):
 
         Returns
         -------
-        Scalar
+        numpy.ndarray
+
+        See also
+        --------
+        angle_with
 
         Notes
         -----
@@ -633,11 +672,25 @@ class Orientation(Misorientation):
 
         where :math:`(g_i \cdot g_j)` is the highest dot product between
         symmetrically equivalent orientations to :math:`g_{i,j}`.
+
+        Examples
+        --------
+        >>> import numpy as np
+        >>> from orix.quaternion import Orientation, symmetry
+        >>> ori1 = Orientation.random((5, 3))
+        >>> ori2 = Orientation.random((6, 2))
+        >>> dist1 = ori1.angle_with_outer(ori2)
+        >>> dist1.shape
+        (6, 2, 5, 3)
+        >>> ori1.symmetry = symmetry.Oh
+        >>> ori2.symmetry = symmetry.Oh
+        >>> dist_sym = ori1.angle_with_outer(ori2)
+        >>> np.allclose(dist1.data, dist_sym.data)
+        False
         """
         ori = self.unit
         if lazy:
-            dot_products = ori._dot_outer_dask(ori, chunk_size=chunk_size)
-
+            dot_products = ori._dot_outer_dask(other, chunk_size=chunk_size)
             # Round because some dot products are slightly above 1
             n_decimals = np.finfo(dot_products.dtype).precision
             dot_products = da.round(dot_products, n_decimals)
@@ -653,11 +706,95 @@ class Orientation(Misorientation):
             else:
                 da.store(sources=angles_dask, targets=angles)
         else:
-            dot_products = ori.dot_outer(ori).data
+            dot_products = ori.dot_outer(other)
             angles = np.arccos(2 * dot_products**2 - 1)
             angles = np.nan_to_num(angles)
 
-        return Scalar(angles)
+        return angles
+
+    def get_distance_matrix(self, lazy=False, chunk_size=20, progressbar=True):
+        r"""The symmetry reduced smallest angle of rotation transforming
+        every orientation in this instance to every other orientation
+        :cite:`johnstone2020density`.
+
+        This is an alternative implementation of
+        :meth:`~orix.quaternion.Misorientation.distance` for
+        a single :class:`Orientation` instance, using :mod:`dask`.
+
+        Parameters
+        ----------
+        lazy : bool, optional
+            Whether to perform the computation lazily with Dask. Default
+            is False.
+        chunk_size : int, optional
+            Number of orientations per axis to include in each iteration
+            of the computation. Default is 20. Only applies when `lazy`
+            is True.
+        progressbar : bool, optional
+            Whether to show a progressbar during computation if `lazy`
+            is True. Default is True.
+
+        Returns
+        -------
+        numpy.ndarray
+
+        Notes
+        -----
+        Given two orientations :math:`g_i` and :math:`g_j`, the smallest
+        angle is considered as the geodesic distance
+
+        .. math::
+
+            d(g_i, g_j) = \arccos(2(g_i \cdot g_j)^2 - 1),
+
+        where :math:`(g_i \cdot g_j)` is the highest dot product between
+        symmetrically equivalent orientations to :math:`g_{i,j}`.
+        """
+        angles = self.angle_with_outer(
+            self, lazy=lazy, chunk_size=chunk_size, progressbar=progressbar
+        )
+        return angles
+
+    def dot(self, other):
+        """Symmetry reduced dot product of orientations in this instance
+        to orientations in another instance, returned as numpy.ndarray.
+
+        See Also
+        --------
+        dot_outer
+        """
+        symmetry = _get_unique_symmetry_elements(self.symmetry, other.symmetry)
+        misorientation = other * ~self
+        all_dot_products = Rotation(misorientation).dot_outer(symmetry)
+        highest_dot_product = np.max(all_dot_products, axis=-1)
+        return highest_dot_product
+
+    def dot_outer(self, other):
+        """Symmetry reduced dot product of every orientation in this
+        instance to every orientation in another instance, returned as
+        numpy.ndarray.
+
+        See Also
+        --------
+        dot
+        """
+        symmetry = _get_unique_symmetry_elements(self.symmetry, other.symmetry)
+        misorientation = other.outer(~self)
+        all_dot_products = Rotation(misorientation).dot_outer(symmetry)
+        highest_dot_product = np.max(all_dot_products, axis=-1)
+        # need to return axes order so that self is first
+        order = tuple(range(self.ndim, self.ndim + other.ndim)) + tuple(
+            range(self.ndim)
+        )
+        return highest_dot_product.transpose(*order)
+
+    @deprecated(
+        since="0.7",
+        alternative="orix.quaternion.Orientation.get_distance_matrix",
+        removal="0.8",
+    )
+    def distance(self, verbose=False, split_size=100):
+        return super().distance(verbose=verbose, split_size=split_size)
 
     def plot_unit_cell(
         self,
@@ -717,40 +854,6 @@ class Orientation(Misorientation):
         if return_figure:
             return fig
 
-    @deprecated(
-        since="0.8",
-        alternative="orix.quaternion.Orientation.map_into_symmetry_reduced_zone",
-        removal="0.9",
-    )
-    def set_symmetry(self, symmetry):
-        """Assign a symmetry to this orientation.
-
-        Computes equivalent transformations which have the smallest
-        angle of rotation and assigns these in-place.
-
-        Parameters
-        ----------
-        symmetry : Symmetry
-
-        Returns
-        -------
-        Orientation
-            The instance itself, with equivalent values.
-
-        Examples
-        --------
-        >>> from orix.quaternion.symmetry import C4
-        >>> data = np.array([[0.5, 0.5, 0.5, 0.5], [0, 1, 0, 0]])
-        >>> o = Orientation(data).set_symmetry(C4)
-        >>> o
-        Orientation (2,) 4
-        [[-0.7071  0.     -0.7071  0.    ]
-        [ 0.      1.      0.      0.    ]]
-        """
-        o = self.__class__(self.data)
-        o.symmetry = symmetry
-        return o.map_into_symmetry_reduced_zone()
-
     def in_euler_fundamental_region(self):
         """Euler angles in the fundamental Euler region of the proper
         subgroup.
@@ -875,7 +978,7 @@ class Orientation(Misorientation):
                 # Determine which hemisphere(s) to show
                 symmetry = self.symmetry
                 sector = symmetry.fundamental_sector
-                if np.any(sector.vertices.polar.data > np.pi / 2):
+                if np.any(sector.vertices.polar > np.pi / 2):
                     hemisphere = "both"
                 else:
                     hemisphere = "upper"
@@ -919,7 +1022,7 @@ class Orientation(Misorientation):
         To read the dot products array `dparr` into memory, do
         `dp = dparr.compute()`.
         """
-        symmetry = self.symmetry.outer(other.symmetry).unique()
+        symmetry = _get_unique_symmetry_elements(self.symmetry, other.symmetry)
         misorientation = other._outer_dask(~self, chunk_size=chunk_size)
 
         # Summation subscripts
