@@ -57,6 +57,9 @@ class Symmetry(Rotation):
         generators = [g for g in self.subgroups if g in other.subgroups]
         return Symmetry.from_generators(*generators)
 
+    def __hash__(self):
+        return hash(self.name.encode() + self.data.tobytes() + self.improper.tobytes())
+
     @property
     def order(self):
         """Number of elements of the group as :class:`int`."""
@@ -237,7 +240,7 @@ class Symmetry(Rotation):
         if name == "-1":
             n = vz
         elif name in ["m11", "1m1", "11m"]:
-            idx_min_angle = np.argmin(self.angle.data)
+            idx_min_angle = np.argmin(self.angle)
             n = self[idx_min_angle].axis
             if name == "m11":
                 n = -n
@@ -448,6 +451,75 @@ class Symmetry(Rotation):
         sr = SphericalRegion(n.unique())
         return sr
 
+    def plot(
+        self,
+        orientation=None,
+        reproject_scatter_kwargs=None,
+        **kwargs,
+    ):
+        """Stereographic projection of symmetry operations.
+
+        The upper hemisphere of the stereographic projection is shown.
+        Vectors on the lower hemisphere are shown after reprojection
+        onto the upper hemisphere.
+
+        Parameters
+        ----------
+        orientation : Orientation, optional
+            The symmetry operations are applied to this orientation
+            before plotting. The default value uses an orientation
+            optimized to show symmetry elements.
+        reproject_scatter_kwargs: dict, optional
+            Dictionary of keyword arguments for the reprojected scatter
+            points which is passed to
+            :meth:`~orix.plot.StereographicPlot.scatter`, which passes
+            these on to :meth:`matplotlib.axes.Axes.scatter`. The
+            default marker style for reprojected vectors is "+". Values
+            used for vector(s) on the visible hemisphere are used unless
+            another value is passed here.
+        kwargs : dict, optional
+            Keyword arguments passed to
+            :meth:`~orix.plot.StereographicPlot.scatter`, which passes
+            these on to :meth:`matplotlib.axes.Axes.scatter`.
+
+        Returns
+        -------
+        fig : matplotlib.figure.Figure
+            The created figure, returned if `return_figure` is supplied
+            as a keyword argument and is True.
+        """
+        if orientation is None:
+            # orientation chosen to mimic stereographic projections as
+            # shown: http://xrayweb.chem.ou.edu/notes/symmetry.html
+            orientation = Rotation.from_axes_angles((-1, 8, 1), np.deg2rad(65))
+        if not isinstance(orientation, Rotation):
+            raise TypeError("Orientation must be a Rotation instance.")
+        orientation = self.outer(orientation)
+
+        kwargs.setdefault("return_figure", False)
+        return_figure = kwargs.pop("return_figure")
+
+        if reproject_scatter_kwargs is None:
+            reproject_scatter_kwargs = {}
+        reproject_scatter_kwargs.setdefault("marker", "+")
+        reproject_scatter_kwargs.setdefault("label", "lower")
+
+        v = orientation * Vector3d.zvector()
+
+        figure = v.scatter(
+            return_figure=True,
+            axes_labels=("a", "b", None),
+            label="upper",
+            reproject=True,
+            reproject_scatter_kwargs=reproject_scatter_kwargs,
+            **kwargs,
+        )
+        # add symmetry name to figure title
+        figure.suptitle(f"${self.name}$")
+
+        if return_figure:
+            return figure
+
 
 # Triclinic
 C1 = Symmetry((1, 0, 0, 0))
@@ -525,7 +597,8 @@ C4 = Symmetry(C4z)
 C4.name = "4"
 
 # Tetragonal
-S4 = Symmetry.from_generators(C2, Ci)
+S4 = Symmetry(C4)
+S4.improper = [0, 1, 0, 1]
 S4.name = "-4"
 C4h = Symmetry.from_generators(C4, Cs)
 C4h.name = "4/m"
@@ -757,7 +830,7 @@ def _get_laue_group_name(name):
         return "-3m"
     elif name in ["6", "-6", "6/m"]:
         return "6/m"
-    elif name in ["6mm", "-6m2", "6/mmm"]:
+    elif name in ["6mm", "-6m2", "6/mmm", "622"]:
         return "6/mmm"
     elif name in ["23", "m-3"]:
         return "m-3"
@@ -765,3 +838,43 @@ def _get_laue_group_name(name):
         return "m-3m"
     else:
         return None
+
+
+def _get_unique_symmetry_elements(sym1, sym2, check_subgroups=False):
+    """Compute the unique symmetry elements between two `Symmetry`
+    instances, defined as `sym1.outer(sym2).unique()`.
+
+    To improve computation speed some checks are performed prior to
+    explicit computation of the unique elements. If `sym1 == sym2`
+    then the unique elements are just the symmetries themselves, and so
+    are returned. If `sym2` is a `subgroup` of `sym1` then the unique
+    symmetry elements will be identical to `sym1`, in this case `sym1`
+    is returned. This check is made if `check_subgroups` is True. As the
+    symmetry order matters, this may not be the case if `sym1` is a
+    subgroup of `sym2`, so this is not checked here.
+
+    If no relationship is determined between the symmetries then the
+    unique symmetry elements are explicitly computed, as described
+    above.
+
+    Parameters
+    ----------
+    sym1, sym2 : Symmetry
+    check_subgroups : bool
+        Whether to check if `sym2` is a subgroup of `sym1`. Default
+        value is False.
+
+    Returns
+    -------
+    unique : Symmetry
+        The unique symmetry elements.
+    """
+    if sym1 == sym2:
+        return sym1
+    if check_subgroups:
+        # test whether sym2 is a subgroup of sym1
+        sym2_is_sg_sym1 = True if sym2 in sym1.subgroups else False
+        if sym2_is_sg_sym1:
+            return sym1
+    # default to explicit computation of the unique symmetry elements
+    return sym1.outer(sym2).unique()
