@@ -27,8 +27,6 @@ import pytest
 from orix.plot import CrystalMapPlot
 from orix.crystal_map import CrystalMap, PhaseList
 
-plt.rcParams["backend"] = "Agg"
-
 # Can be easily changed in the future
 PLOT_MAP = "plot_map"
 
@@ -87,7 +85,7 @@ class TestCrystalMapPlot:
     def test_plot_scalar(self, crystal_map):
         cm = crystal_map
 
-        angles = cm.rotations.angle.data
+        angles = cm.rotations.angle
 
         fig1 = plt.figure()
         ax1 = fig1.add_subplot(projection=PLOT_MAP)
