@@ -33,9 +33,9 @@ from orix.quaternion.symmetry import (
     T,
     O,
     Oh,
+    _groups,
     _proper_groups,
 )
-from orix.scalar import Scalar
 from orix.vector import AxAngle, Vector3d
 
 
@@ -91,6 +91,7 @@ def test_orientation_persistence(symmetry, vector):
     assert v1._tuples == v2._tuples
 
 
+# TODO: Remove in 0.10
 @pytest.mark.parametrize(
     "orientation, symmetry, expected",
     [
@@ -115,7 +116,8 @@ def test_orientation_persistence(symmetry, vector):
 def test_distance(orientation, symmetry, expected):
     orientation.symmetry = symmetry
     orientation = orientation.map_into_symmetry_reduced_zone(verbose=True)
-    distance = orientation.distance(verbose=True)
+    with pytest.warns(np.VisibleDeprecationWarning, match="Function "):
+        distance = orientation.distance(verbose=True)
     assert np.allclose(distance, expected, atol=1e-3)
 
 
@@ -240,6 +242,14 @@ def test_transpose_2d():
     assert o1.shape == o2.shape[::-1]
 
 
+def test_map_into_reduced_symmetry_zone_verbose():
+    o = Orientation.random()
+    o.symmetry = Oh
+    o1 = o.map_into_symmetry_reduced_zone()
+    o2 = o.map_into_symmetry_reduced_zone(verbose=True)
+    assert np.allclose(o1.data, o2.data)
+
+
 @pytest.mark.parametrize(
     "shape, expected_shape, axes",
     [((11, 3, 5), (11, 5, 3), (0, 2, 1)), ((11, 3, 5), (3, 5, 11), (1, 2, 0))],
@@ -307,6 +317,100 @@ def test_symmetry_property_wrong_number_of_values_misorientation(error_type, val
         o.symmetry = value
 
 
+class TestMisorientation:
+    def test_get_distance_matrix(self):
+        """Compute distance between every misorientation in an instance
+        with every other misorientation in the same instance.
+
+        Misorientations are taken from the misorientation clustering
+        user guide.
+        """
+        m1 = Misorientation(
+            [
+                [-0.8541, -0.5201, -0.0053, -0.0002],
+                [-0.8486, -0.5291, -0.0019, -0.0018],
+                [-0.7851, -0.6194, -0.0043, -0.0004],
+                [-0.7802, -0.3136, -0.5413, -0.0029],
+                [-0.8518, -0.5237, -0.0004, -0.0102],
+            ],
+            symmetry=(D6, D6),
+        )
+        distance1 = m1.get_distance_matrix()
+        assert np.allclose(np.diag(distance1), 0)
+        expected = np.array(
+            [
+                [0, 0.0224, 0.2420, 0.2580, 0.0239],
+                [0.0224, 0, 0.2210, 0.2367, 0.0212],
+                [0.2419, 0.2209, 0, 0.0184, 0.2343],
+                [0.2579, 0.2367, 0.0184, 0, 0.2496],
+                [0.0239, 0.0212, 0.2343, 0.2497, 0],
+            ]
+        )
+        assert np.allclose(distance1, expected, atol=1e-4)
+
+    def test_get_distance_matrix_shape(self):
+        shape = (3, 4)
+        m2 = Misorientation.random(shape)
+        distance2 = m2.get_distance_matrix()
+        assert distance2.shape == 2 * shape
+
+    def test_get_distance_matrix_progressbar_chunksize(self):
+        m = Misorientation.random((5, 15, 4))
+        angle1 = m.get_distance_matrix(chunk_size=5, progressbar=True)
+        angle2 = m.get_distance_matrix(chunk_size=10, progressbar=False)
+        assert np.allclose(angle1, angle2)
+
+    @pytest.mark.parametrize("symmetry", _groups[:-1])
+    def test_get_distance_matrix_equal_explicit_calculation(self, symmetry):
+        # do not test Oh, as this takes ~4 GB
+        m = Misorientation.random((5,))
+        m.symmetry = (symmetry, symmetry)
+        angle1 = m.get_distance_matrix()
+        s1, s2 = m.symmetry
+        # computation of mismisorientation
+        # eq 6 in Johnstone et al. 2020
+        p1 = s1.outer(m).outer(s2)
+        p2 = s1.outer(~m).outer(s2)
+        # for identical symmetries this is equivalent to the old
+        # distance function:
+        # d = s2.outer(~m).outer(s1.outer(s1)).outer(m).outer(s2)
+        p12 = p1.outer(p2)
+        angle2 = p12.angle.min(axis=(0, 2, 3, 5))
+        assert np.allclose(angle1, angle2)
+
+    # TODO: Remove in 0.10
+    @pytest.mark.parametrize("symmetry", _groups[:-1])
+    def test_get_distance_matrix_equal_distance(self, symmetry):
+        # do not test Oh, as this takes ~4 GB
+        shape = (3, 2)
+        n = np.prod(shape)
+        m = Misorientation.random(shape)
+        m.symmetry = (symmetry, symmetry)
+        angle1 = m.get_distance_matrix().reshape(n, n, order="F")
+        m1 = m.flatten()
+        angle2 = m1.get_distance_matrix()
+        assert np.allclose(angle1, angle2)
+        with pytest.warns(np.VisibleDeprecationWarning, match="Function "):
+            angle3 = m1.distance()
+        assert np.allclose(angle1, angle3)
+
+
+def test_orientation_equality():
+    # symmetries must also be the same to be equal
+    o1 = Orientation.random((6, 5))
+    o2 = Orientation(o1)
+    assert o1 == o2
+    o1.symmetry = C4
+    o2.symmetry = o1.symmetry
+    assert o1 == o2
+    o2.symmetry = C3
+    assert o1 != o2
+    o3 = Orientation.random((6,))
+    assert o1 != o3
+    o3.symmetry = o1.symmetry
+    assert o1 != o3
+
+
 class TestOrientationInitialization:
     def test_from_euler_symmetry(self):
         euler = np.deg2rad([90, 45, 90])
@@ -364,6 +468,75 @@ class TestOrientationInitialization:
         assert ori.symmetry.name == ori2.symmetry.name == "m-3m"
         assert np.allclose(ori.symmetry.data, ori2.symmetry.data)
 
+    def test_get_identity(self):
+        """Get the identity orientation via two alternative routes."""
+        o1 = Orientation([0.4884, 0.1728, 0.2661, 0.8129])
+        o2 = Orientation([0.8171, -0.2734, 0.161, -0.4813])
+
+        # Route 1 from a Misorientation instance
+        m12_1 = o2 - o1
+        o3_1 = (m12_1 * o1) * ~o2
+
+        # Route 2 from a third Orientation instance
+        m12_2 = o2 * ~o1
+        o3_2 = (m12_2 * o1) * ~o2
+
+        assert np.allclose(m12_1.data, m12_2.data)
+        assert np.allclose(o3_1.data, o3_2.data)
+        assert np.allclose(o3_1.data, [1, 0, 0, 0])
+
+    # TODO: Remove in 1.0
+    def test_from_euler_warns(self):
+        """Orientation.from_euler() warns only once when "convention"
+        argument is passed.
+        """
+        euler = np.random.rand(10, 3)
+
+        with pytest.warns(None) as record1:
+            _ = Orientation.from_euler(euler)
+        assert len(record1) == 0
+
+        msg = (
+            r"Argument `convention` is deprecated and will be removed in version 1.0. "
+            r"To avoid this warning, please do not use `convention`. "
+            r"Use `direction` instead. See the documentation of `from_euler\(\)` for "
+            "more details."
+        )
+        with pytest.warns(np.VisibleDeprecationWarning, match=msg) as record2:
+            _ = Orientation.from_euler(euler, convention="whatever")
+        assert len(record2) == 1
+
+    # TODO: Remove in 1.0
+    def test_from_euler_convention_mtex(self):
+        """Passing convention="mtex" to Orientation.from_euler() works
+        but warns once.
+        """
+        euler = np.random.rand(10, 3)
+        ori1 = Orientation.from_euler(euler, direction="crystal2lab")
+        with pytest.warns(np.VisibleDeprecationWarning, match=r"Argument `convention`"):
+            ori2 = Orientation.from_euler(euler, convention="mtex")
+        assert np.allclose(ori1.data, ori2.data)
+
+    # TODO: Remove in 1.0
+    def test_to_euler_convention_warns(self):
+        """Orientation.to_euler() warns only once when "convention"
+        argument is passed.
+        """
+        ori1 = Orientation.from_euler(np.random.rand(10, 3))
+
+        with pytest.warns(None) as record:
+            ori2 = ori1.to_euler()
+        assert len(record) == 0
+
+        msg = (
+            r"Argument `convention` is deprecated and will be removed in version 1.0. "
+            r"To avoid this warning, please do not use `convention`. "
+            r"See the documentation of `to_euler\(\)` for more details."
+        )
+        with pytest.warns(np.VisibleDeprecationWarning, match=msg):
+            ori3 = ori1.to_euler(convention="whatever")
+        assert np.allclose(ori2, ori3)
+
 
 class TestOrientation:
     @pytest.mark.parametrize("symmetry", [C1, C2, C3, C4, D2, D3, D6, T, O, Oh])
@@ -372,14 +545,15 @@ class TestOrientation:
         o = Orientation(q, symmetry=symmetry)
         o = o.map_into_symmetry_reduced_zone()
         angles_numpy = o.get_distance_matrix()
-        assert isinstance(angles_numpy, Scalar)
+        assert isinstance(angles_numpy, np.ndarray)
         assert angles_numpy.shape == (2, 2)
 
         angles_dask = o.get_distance_matrix(lazy=True)
-        assert isinstance(angles_dask, Scalar)
+        assert isinstance(angles_dask, np.ndarray)
         assert angles_dask.shape == (2, 2)
 
         assert np.allclose(angles_numpy.data, angles_dask.data)
+        assert np.allclose(np.diag(angles_numpy.data), 0)
 
     def test_get_distance_matrix_lazy_parameters(self):
         shape = (5, 15, 4)
@@ -392,13 +566,60 @@ class TestOrientation:
 
         assert np.allclose(angle1.data, angle2.data)
 
+    @pytest.mark.parametrize("symmetry", [C1, C2, C3, C4, D2, D3, D6, T, O, Oh])
+    def test_angle_with_outer(self, symmetry):
+        shape = (5,)
+        o = Orientation.random(shape)
+        o.symmetry = symmetry
+
+        dist = o.get_distance_matrix()
+        awo_self = o.angle_with_outer(o)
+        assert awo_self.shape == shape + shape
+        assert np.allclose(dist, awo_self)
+        assert np.allclose(np.diag(awo_self), 0, atol=1e-6)
+
+        o2 = Orientation.random((6,))
+        dist = o.angle_with_outer(o2)
+        assert dist.shape == o.shape + o2.shape
+
+        dist2 = o2.angle_with_outer(o)
+        assert dist2.shape == o2.shape + o.shape
+
+        assert np.allclose(dist, dist2.T)
+
+    def test_angle_with_outer_shape(self):
+        shape1 = (6, 5)
+        shape2 = (7, 2)
+        o1 = Orientation.random(shape1)
+        o2 = Orientation.random(shape2)
+
+        awo_o12 = o1.angle_with_outer(o2)
+        assert awo_o12.shape == shape1 + shape2
+
+        awo_o21 = o2.angle_with_outer(o1)
+        assert awo_o21.shape == shape2 + shape1
+
+        r1 = Rotation(o1)
+        r2 = Rotation(o2)
+        awo_r12 = r1.angle_with_outer(r2)
+        awo_r21 = r2.angle_with_outer(r1)
+        assert awo_o12.shape == awo_r12.shape
+        assert awo_o21.shape == awo_r21.shape
+        assert np.allclose(awo_o12, awo_r12)
+        assert np.allclose(awo_o21, awo_r21)
+
+        o1.symmetry = Oh
+        awo_o12s = o1.angle_with_outer(o2)
+        assert awo_o12s.shape == awo_r12.shape
+        assert not np.allclose(awo_o12s, awo_r12)
+
     @pytest.mark.parametrize("symmetry", [C1, C2, C3, C4, D2, D3, D6, T, O, Oh])
     def test_angle_with(self, symmetry):
         q = [(0.5, 0.5, 0.5, 0.5), (0.5**0.5, 0, 0, 0.5**0.5)]
         r = Rotation(q)
         o = Orientation(q, symmetry=symmetry)
 
-        is_equal = np.allclose((~o).angle_with(o).data, (~r).angle_with(r).data)
+        is_equal = np.allclose((~o).angle_with(o), (~r).angle_with(r))
         if symmetry.name in ["1", "m3m"]:
             assert is_equal
         else:
@@ -468,7 +689,7 @@ class TestOrientation:
         axes = fig.axes[0]
         assert isinstance(axes, InversePoleFigurePlot)
         assert len(fig.axes) == 1
-        assert axes._direction.dot(vz).data[0] == 1
+        assert axes._direction.dot(vz)[0] == 1
         assert axes._hemisphere == "upper"
 
         # It's possible to add to an existing figure
@@ -517,33 +738,3 @@ class TestOrientation:
             ori.symmetry = pg
             region = np.radians(pg.euler_fundamental_region)
             assert np.all(np.max(ori.in_euler_fundamental_region(), axis=0) <= region)
-
-
-def test_set_symmetry_deprecation_warning_orientation():
-    o = Orientation.random((3, 2))
-    with pytest.warns(np.VisibleDeprecationWarning, match="Function `set_symmetry()"):
-        _ = o.set_symmetry(C2)
-
-
-def test_set_symmetry_deprecation_warning_misorientation():
-    o = Misorientation.random((3, 2))
-    with pytest.warns(np.VisibleDeprecationWarning, match="Function `set_symmetry()"):
-        _ = o.set_symmetry(C2, C2)
-
-
-def test_get_identity():
-    """Get the identity orientation via two alternative routes."""
-    o1 = Orientation([0.4884, 0.1728, 0.2661, 0.8129])
-    o2 = Orientation([0.8171, -0.2734, 0.161, -0.4813])
-
-    # Route 1 from a Misorientation instance
-    m12_1 = o2 - o1
-    o3_1 = (m12_1 * o1) * ~o2
-
-    # Route 2 from a third Orientation instance
-    m12_2 = o2 * ~o1
-    o3_2 = (m12_2 * o1) * ~o2
-
-    assert np.allclose(m12_1.data, m12_2.data)
-    assert np.allclose(o3_1.data, o3_2.data)
-    assert np.allclose(o3_1.data, [1, 0, 0, 0])
