@@ -23,7 +23,7 @@ import pytest
 from orix.crystal_map import Phase
 from orix.quaternion import Orientation, symmetry
 from orix.vector import Miller
-from orix.vector.miller import _round_indices, _uvw2UVTW, _UVTW2uvw
+from orix.vector.miller import _round_indices, _uvw2UVTW, _UVTW2uvw, _transform_space
 
 
 TRIGONAL_PHASE = Phase(
@@ -195,17 +195,17 @@ class TestMiller:
 
         # Test from MTEX' v5.6.0 documentation
         m = Miller(UVTW=[1, -2, 1, 3], phase=TRIGONAL_PHASE)
-        _, l = m.symmetrise(return_multiplicity=True, unique=True)
-        assert l == 6
+        _, mult = m.symmetrise(return_multiplicity=True, unique=True)
+        assert mult == 6
 
         m2 = Miller(uvw=[[1, 0, 0], [1, 1, 0], [1, 1, 1]], phase=CUBIC_PHASE)
         _, idx = m2.symmetrise(unique=True, return_index=True)
         assert np.allclose(idx, np.array([0] * 6 + [1] * 12 + [2] * 8))
 
-        _, l3, _ = m2.symmetrise(
+        _, mult2, _ = m2.symmetrise(
             unique=True, return_multiplicity=True, return_index=True
         )
-        assert np.allclose(l3, [6, 12, 8])
+        assert np.allclose(mult2, [6, 12, 8])
 
     def test_unique(self):
         # From the "Crystal geometry" notebook
@@ -356,6 +356,26 @@ class TestMiller:
         assert np.allclose(h4.phase.point_group.data, h.phase.point_group.data)
         assert np.allclose(h4.data, (1.366, 0.366, 0), atol=1e-3)
 
+    def test_transform_space(self):
+        """Cover all lines in private function."""
+        lattice = TETRAGONAL_LATTICE
+
+        # Don't share memory
+        v1 = np.array([1, 1, 1])
+        v2 = _transform_space(v1, "d", "d", lattice)
+        assert not np.may_share_memory(v1, v2)
+
+        # Incorrect space
+        with pytest.raises(ValueError, match="`space_in` and `space_out` must be one "):
+            _transform_space(v1, "direct", "cartesian", lattice)
+
+        # uvw -> hkl -> uvw
+        v3 = np.array([1, 0, 1])
+        v4 = _transform_space(v3, "d", "r", lattice)
+        v5 = _transform_space(v4, "r", "d", lattice)
+        assert np.allclose(v4, [0.25, 0, 1])
+        assert np.allclose(v5, v3)
+
 
 class TestMillerBravais:
     def test_uvw2UVTW(self):
@@ -463,8 +483,8 @@ class TestMillerBravais:
         m6 = Miller(hkil=[1, 1, -2, 0], phase=TRIGONAL_PHASE)
         m7 = Miller(hkil=[-1, -1, 2, 0], phase=TRIGONAL_PHASE)
 
-        assert np.allclose(np.rad2deg(m6.angle_with(m7).data[0]), 180)
-        assert np.allclose(np.rad2deg(m6.angle_with(m7, use_symmetry=True).data[0]), 60)
+        assert np.allclose(np.rad2deg(m6.angle_with(m7)[0]), 180)
+        assert np.allclose(np.rad2deg(m6.angle_with(m7, use_symmetry=True)[0]), 60)
 
     def test_convention_not_met(self):
         with pytest.raises(ValueError, match="The Miller-Bravais indices convention"):
@@ -494,8 +514,8 @@ class TestDeGraefExamples:
         # Example 1.3, 1.4: Dot product and angle between two directions
         m2 = Miller(uvw=[1, 2, 0], phase=TETRAGONAL_PHASE)
         m3 = Miller(uvw=[3, 1, 1], phase=TETRAGONAL_PHASE)
-        assert np.allclose(m2.dot(m3).data, 5 / 4)  # nm^2
-        assert np.allclose(np.rad2deg(m2.angle_with(m3).data[0]), 53.30, atol=0.01)
+        assert np.allclose(m2.dot(m3), 5 / 4)  # nm^2
+        assert np.allclose(np.rad2deg(m2.angle_with(m3)[0]), 53.30, atol=0.01)
 
         # Example 1.5: Reciprocal metric tensor
         lattice_recip = lattice.reciprocal()
@@ -504,7 +524,7 @@ class TestDeGraefExamples:
         # Example 1.6, 1.7: Angle between two plane normals
         m4 = Miller(hkl=[1, 2, 0], phase=TETRAGONAL_PHASE)
         m5 = Miller(hkl=[3, 1, 1], phase=TETRAGONAL_PHASE)
-        assert np.allclose(np.rad2deg(m4.angle_with(m5).data[0]), 45.7, atol=0.1)
+        assert np.allclose(np.rad2deg(m4.angle_with(m5)[0]), 45.7, atol=0.1)
 
         # Example 1.8: Reciprocal components of a lattice vector
         m6 = Miller(uvw=[1, 1, 4], phase=TETRAGONAL_PHASE)
@@ -944,19 +964,19 @@ class TestMillerPointGroupsTetragonal(TestMillerPointGroups):
             m.symmetrise(unique=False).hkl,
             [
                 [ 0,  0,  1],
+                [ 0,  0, -1],
                 [ 0,  0,  1],
                 [ 0,  0, -1],
-                [ 0,  0, -1],
-
+                
                 [ 0,  1,  1],
+                [ 1,  0, -1],
                 [ 0, -1,  1],
-                [ 0, -1, -1],
-                [ 0,  1, -1],
-
+                [-1,  0, -1],
+                
                 [ 1,  1,  1],
+                [ 1, -1, -1],
                 [-1, -1,  1],
-                [-1, -1, -1],
-                [ 1,  1, -1],
+                [-1,  1, -1],
             ],
         )
         m_unique = m.symmetrise(unique=True)
@@ -967,14 +987,14 @@ class TestMillerPointGroupsTetragonal(TestMillerPointGroups):
                 [ 0,  0, -1],
 
                 [ 0,  1,  1],
+                [ 1,  0, -1],
                 [ 0, -1,  1],
-                [ 0, -1, -1],
-                [ 0,  1, -1],
-
+                [-1,  0, -1],
+                
                 [ 1,  1,  1],
+                [ 1, -1, -1],
                 [-1, -1,  1],
-                [-1, -1, -1],
-                [ 1,  1, -1],
+                [-1,  1, -1],
             ],
         )
         # fmt: on
