@@ -1,8 +1,25 @@
-import pytest
-import numpy as np
+# -*- coding: utf-8 -*-
+# Copyright 2018-2022 the orix developers
+#
+# This file is part of orix.
+#
+# orix is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# orix is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with orix.  If not, see <http://www.gnu.org/licenses/>.
 
-from orix.vector import Vector3d
-from orix.vector.spherical_region import SphericalRegion
+import numpy as np
+import pytest
+
+from orix.vector import Vector3d, SphericalRegion
 
 
 @pytest.fixture(params=[(0, 0, 1)])
