@@ -20,8 +20,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 import pytest
 
-from orix.quaternion import symmetry
-from orix.scalar import Scalar
+from orix.quaternion import Orientation, symmetry
 from orix.vector import Vector3d, check_vector
 
 
@@ -85,7 +84,7 @@ def test_neg(vector):
     "vector, other, expected",
     [
         ([1, 2, 3], Vector3d([[1, 2, 3], [-3, -2, -1]]), [[2, 4, 6], [-2, 0, 2]]),
-        ([1, 2, 3], Scalar([4]), [5, 6, 7]),
+        ([1, 2, 3], [4], [5, 6, 7]),
         ([1, 2, 3], 0.5, [1.5, 2.5, 3.5]),
         ([1, 2, 3], [-1, 2], [[0, 1, 2], [3, 4, 5]]),
         ([1, 2, 3], np.array([-1, 1]), [[0, 1, 2], [2, 3, 4]]),
@@ -104,7 +103,7 @@ def test_add(vector, other, expected):
     "vector, other, expected",
     [
         ([1, 2, 3], Vector3d([[1, 2, 3], [-3, -2, -1]]), [[0, 0, 0], [4, 4, 4]]),
-        ([1, 2, 3], Scalar([4]), [-3, -2, -1]),
+        ([1, 2, 3], [4], [-3, -2, -1]),
         ([1, 2, 3], 0.5, [0.5, 1.5, 2.5]),
         ([1, 2, 3], [-1, 2], [[2, 3, 4], [-1, 0, 1]]),
         ([1, 2, 3], np.array([-1, 1]), [[2, 3, 4], [0, 1, 2]]),
@@ -128,7 +127,7 @@ def test_sub(vector, other, expected):
             [[0, 0, 0], [4, 4, 4]],
             marks=pytest.mark.xfail(raises=ValueError),
         ),
-        ([1, 2, 3], Scalar([4]), [4, 8, 12]),
+        ([1, 2, 3], [4], [4, 8, 12]),
         ([1, 2, 3], 0.5, [0.5, 1.0, 1.5]),
         ([1, 2, 3], [-1, 2], [[-1, -2, -3], [2, 4, 6]]),
         ([1, 2, 3], np.array([-1, 1]), [[-1, -2, -3], [1, 2, 3]]),
@@ -152,7 +151,7 @@ def test_mul(vector, other, expected):
             [[0, 0, 0], [4, 4, 4]],
             marks=pytest.mark.xfail(raises=ValueError),
         ),
-        ([4, 8, 12], Scalar([4]), [1, 2, 3]),
+        ([4, 8, 12], [4], [1, 2, 3]),
         ([0.5, 1.0, 1.5], 0.5, [1, 2, 3]),
         (
             [1, 2, 3],
@@ -181,8 +180,8 @@ def test_rdiv():
 
 
 def test_dot(vector, something):
-    assert np.allclose(vector.dot(vector).data, (vector.data**2).sum(axis=-1))
-    assert np.allclose(vector.dot(something).data, something.dot(vector).data)
+    assert np.allclose(vector.dot(vector), (vector.data**2).sum(axis=-1))
+    assert np.allclose(vector.dot(something), something.dot(vector))
 
 
 def test_dot_error(vector, number):
@@ -191,11 +190,11 @@ def test_dot_error(vector, number):
 
 
 def test_dot_outer(vector, something):
-    d = vector.dot_outer(something).data
+    d = vector.dot_outer(something)
     assert d.shape == vector.shape + something.shape
     for i in np.ndindex(vector.shape):
         for j in np.ndindex(something.shape):
-            assert np.allclose(d[i + j], vector[i].dot(something[j]).data)
+            assert np.allclose(d[i + j], vector[i].dot(something[j]))
 
 
 def test_cross(vector, something):
@@ -237,9 +236,9 @@ def test_zero(shape):
 
 
 def test_angle_with(vector, something):
-    a = vector.angle_with(vector).data
+    a = vector.angle_with(vector)
     assert np.allclose(a, 0)
-    a = vector.angle_with(something).data
+    a = vector.angle_with(something)
     assert np.all(a >= 0)
     assert np.all(a <= np.pi)
 
@@ -339,7 +338,7 @@ def test_assign_z(vector, data, expected):
     indirect=["vector"],
 )
 def test_perpendicular(vector: Vector3d):
-    assert np.allclose(vector.dot(vector.perpendicular).data, 0)
+    assert np.allclose(vector.dot(vector.perpendicular), 0)
 
 
 def test_mean_xyz():
@@ -453,9 +452,7 @@ class TestSphericalCoordinates:
 
     def test_polar_loop(self, vector):
         azimuth, polar, radial = vector.to_polar()
-        vector2 = Vector3d.from_polar(
-            azimuth=azimuth.data, polar=polar.data, radial=radial.data
-        )
+        vector2 = Vector3d.from_polar(azimuth=azimuth, polar=polar, radial=radial)
         assert np.allclose(vector.data, vector2.data)
 
 
@@ -466,8 +463,8 @@ class TestGetCircle:
         c = v.get_circle(opening_angle=oa, steps=101)
 
         assert c.size == 101
-        assert np.allclose(c.z.data, 0)
-        assert np.allclose(v.angle_with(c).data, oa)
+        assert np.allclose(c.z, 0)
+        assert np.allclose(v.angle_with(c), oa)
         assert np.allclose(c.mean().data, [0, 0, 0], atol=1e-2)
         assert np.allclose(v.cross(c[0, 0]).data, [1, 0, 0])
 
@@ -562,6 +559,31 @@ class TestPlotting:
         ):
             self.v.scatter(projection="equal_angle")
 
+    def test_scatter_reproject(self):
+        o = Orientation.from_axes_angles((-1, 8, 1), np.deg2rad(65))
+        v = (symmetry.Oh * o) * Vector3d.zvector()
+        # normal scatter: half of the vectors are shown
+        fig1 = v.scatter(hemisphere="upper", reproject=False, return_figure=True)
+        assert (
+            sum(len(c.get_offsets()) for c in fig1.axes[0].collections) == v.size // 2
+        )
+        # reproject: all of the vectors are shown
+        fig2 = v.scatter(hemisphere="upper", reproject=True, return_figure=True, c="r")
+        assert sum(len(c.get_offsets()) for c in fig2.axes[0].collections) == v.size
+        # (1, 0, 0, 1) is red in RGBA
+        assert all(
+            np.allclose(c.get_edgecolor(), (1, 0, 0, 1))
+            for c in fig2.axes[0].collections
+        )
+        # reproject: all of the vectors are shown
+        fig3 = v.scatter(hemisphere="lower", reproject=True, return_figure=True)
+        assert sum(len(c.get_offsets()) for c in fig3.axes[0].collections) == v.size
+        # reproject hemisphere="both": reprojection is ignored so
+        # half of the vectors are shown on each axes as normal
+        fig4 = v.scatter(hemisphere="both", reproject=True, return_figure=True)
+        for ax in fig4.axes:
+            assert sum(len(c.get_offsets()) for c in ax.collections) == v.size // 2
+
     def test_draw_circle(self):
         v = self.v
         colors = [f"C{i}" for i in range(v.size)]
@@ -600,6 +622,45 @@ class TestPlotting:
 
         plt.close("all")
 
+    def test_draw_circle_reproject(self):
+        """Ensure that parts of circles on the other hemisphere are
+        added with correct appearance to `StereographicPlot.lines`.
+        """
+        v = Vector3d([(1, 1, 1), (-1, 1, 1)])
+
+        fig1 = v.draw_circle(return_figure=True)
+        assert len(fig1.axes[0].lines) == 2
+
+        fig2 = v.draw_circle(reproject=True, return_figure=True, linewidth=2)
+        circles2 = fig2.axes[0].lines
+        assert len(circles2) == 4
+        for c, style in zip(circles2, ["-", "-", "--", "--"]):
+            assert c.get_linestyle() == style
+            assert c.get_color() == "C0"
+            assert c.get_linewidth() == 2
+
+        fig3 = v.draw_circle(
+            reproject=True,
+            return_figure=True,
+            color=["r", "g"],
+            reproject_plot_kwargs=dict(linestyle="-."),
+        )
+        circles3 = fig3.axes[0].lines
+        assert len(circles3) == 4
+        for c, style, color in zip(
+            circles3, ["-", "-", "-.", "-."], ["r", "g", "r", "g"]
+        ):
+            assert c.get_linestyle() == style
+            assert c.get_color() == color
+
+        # Cover line where `reproject_plot_kwargs` is not passed
+        # directly to `StereographicPlot.draw_circle()`
+        fig4, ax4 = plt.subplots(subplot_kw=dict(projection="stereographic"))
+        ax4.draw_circle(v, reproject=True)
+        circles4 = ax4.lines
+        assert len(circles4) == 4
+        assert all([c.get_color() == "C0" for c in circles4])
+
 
 class TestProjectingToFundamentalSector:
     def test_in_fundamental_sector_oh(self):
