@@ -22,7 +22,6 @@ import matplotlib.pyplot as plt
 import numpy as np
 
 from orix.base import check, Object3d
-from orix.scalar import Scalar
 
 
 def check_vector(obj):
@@ -49,8 +48,7 @@ class Vector3d(Object3d):
     >>> v = Vector3d((1, 2, 3))
     >>> w = Vector3d(np.array([[1, 0, 0], [0, 1, 1]]))
     >>> w.x
-    Scalar (2,)
-    [1 0]
+    array([1, 0])
     >>> v.unit
     Vector3d (1,)
     [[ 0.2673  0.5345  0.8018]]
@@ -81,8 +79,8 @@ class Vector3d(Object3d):
 
     @property
     def x(self):
-        """Scalar : This vector's x data."""
-        return Scalar(self.data[..., 0])
+        """numpy.ndarray : This vector's x data."""
+        return self.data[..., 0]
 
     @x.setter
     def x(self, value):
@@ -90,8 +88,8 @@ class Vector3d(Object3d):
 
     @property
     def y(self):
-        """Scalar : This vector's y data."""
-        return Scalar(self.data[..., 1])
+        """numpy.ndarray : This vector's y data."""
+        return self.data[..., 1]
 
     @y.setter
     def y(self, value):
@@ -99,8 +97,8 @@ class Vector3d(Object3d):
 
     @property
     def z(self):
-        """Scalar : This vector's z data."""
-        return Scalar(self.data[..., 2])
+        """numpy.ndarray : This vector's z data."""
+        return self.data[..., 2]
 
     @z.setter
     def z(self, value):
@@ -109,7 +107,7 @@ class Vector3d(Object3d):
     @property
     def xyz(self):
         """tuple of ndarray : This vector's components, useful for plotting."""
-        return self.x.data, self.y.data, self.z.data
+        return self.x, self.y, self.z
 
     @property
     def _tuples(self):
@@ -120,12 +118,12 @@ class Vector3d(Object3d):
 
     @property
     def perpendicular(self):
-        if np.any(self.x.data == 0) and np.any(self.y.data == 0):
-            if np.any(self.z.data == 0):
+        if np.any(self.x == 0) and np.any(self.y == 0):
+            if np.any(self.z == 0):
                 raise ValueError("No vectors are perpendicular")
             return Vector3d.xvector()
-        x = -self.y.data
-        y = self.x.data
+        x = -self.y
+        y = self.x
         z = np.zeros_like(x)
         return Vector3d(np.stack((x, y, z), axis=-1))
 
@@ -137,12 +135,10 @@ class Vector3d(Object3d):
 
         Returns
         -------
-        Scalar
+        numpy.ndarray
         """
-        return Scalar(
-            np.sqrt(
-                self.data[..., 0] ** 2 + self.data[..., 1] ** 2 + self.data[..., 2] ** 2
-            )
+        return np.sqrt(
+            self.data[..., 0] ** 2 + self.data[..., 1] ** 2 + self.data[..., 2] ** 2
         )
 
     @property
@@ -154,11 +150,11 @@ class Vector3d(Object3d):
 
         Returns
         -------
-        Scalar
+        numpy.ndarray
         """
         azimuth = np.arctan2(self.data[..., 1], self.data[..., 0])
         azimuth += (azimuth < 0) * 2 * np.pi
-        return Scalar(azimuth)
+        return azimuth
 
     @property
     def polar(self):
@@ -169,9 +165,9 @@ class Vector3d(Object3d):
 
         Returns
         -------
-        Scalar
+        numpy.ndarray
         """
-        return Scalar(np.arccos(self.data[..., 2] / self.radial.data))
+        return np.arccos(self.data[..., 2] / self.radial.data)
 
     def __neg__(self):
         return self.__class__(-self.data)
@@ -179,49 +175,49 @@ class Vector3d(Object3d):
     def __add__(self, other):
         if isinstance(other, Vector3d):
             return self.__class__(self.data + other.data)
-        elif isinstance(other, Scalar):
-            return self.__class__(self.data + other.data[..., np.newaxis])
         elif isinstance(other, (int, float)):
             return self.__class__(self.data + other)
         elif isinstance(other, (list, tuple)):
             other = np.array(other)
+
         if isinstance(other, np.ndarray):
             return self.__class__(self.data + other[..., np.newaxis])
+
         return NotImplemented
 
     def __radd__(self, other):
-        if isinstance(other, Scalar):
-            return self.__class__(other.data[..., np.newaxis] + self.data)
-        elif isinstance(other, (int, float)):
+        if isinstance(other, (int, float)):
             return self.__class__(other + self.data)
         elif isinstance(other, (list, tuple)):
             other = np.array(other)
+
         if isinstance(other, np.ndarray):
             return self.__class__(other[..., np.newaxis] + self.data)
+
         return NotImplemented
 
     def __sub__(self, other):
         if isinstance(other, Vector3d):
             return self.__class__(self.data - other.data)
-        elif isinstance(other, Scalar):
-            return self.__class__(self.data - other.data[..., np.newaxis])
         elif isinstance(other, (int, float)):
             return self.__class__(self.data - other)
         elif isinstance(other, (list, tuple)):
             other = np.array(other)
+
         if isinstance(other, np.ndarray):
             return self.__class__(self.data - other[..., np.newaxis])
+
         return NotImplemented
 
     def __rsub__(self, other):
-        if isinstance(other, Scalar):
-            return self.__class__(other.data[..., np.newaxis] - self.data)
-        elif isinstance(other, (int, float)):
+        if isinstance(other, (int, float)):
             return self.__class__(other - self.data)
         elif isinstance(other, (list, tuple)):
             other = np.array(other)
+
         if isinstance(other, np.ndarray):
             return self.__class__(other[..., np.newaxis] - self.data)
+
         return NotImplemented
 
     def __mul__(self, other):
@@ -230,38 +226,38 @@ class Vector3d(Object3d):
                 "Multiplying one vector with another is ambiguous. "
                 "Try `.dot` or `.cross` instead."
             )
-        elif isinstance(other, Scalar):
-            return self.__class__(self.data * other.data[..., np.newaxis])
         elif isinstance(other, (int, float)):
             return self.__class__(self.data * other)
         elif isinstance(other, (list, tuple)):
             other = np.array(other)
+
         if isinstance(other, np.ndarray):
             return self.__class__(self.data * other[..., np.newaxis])
+
         return NotImplemented
 
     def __rmul__(self, other):
-        if isinstance(other, Scalar):
-            return self.__class__(other.data[..., np.newaxis] * self.data)
-        elif isinstance(other, (int, float)):
+        if isinstance(other, (int, float)):
             return self.__class__(other * self.data)
         elif isinstance(other, (list, tuple)):
             other = np.array(other)
+
         if isinstance(other, np.ndarray):
             return self.__class__(other[..., np.newaxis] * self.data)
+
         return NotImplemented
 
     def __truediv__(self, other):
         if isinstance(other, Vector3d):
             raise ValueError("Dividing vectors is undefined")
-        elif isinstance(other, Scalar):
-            return self.__class__(self.data / other.data[..., np.newaxis])
         elif isinstance(other, (int, float)):
             return self.__class__(self.data / other)
         elif isinstance(other, (list, tuple)):
             other = np.array(other)
+
         if isinstance(other, np.ndarray):
             return self.__class__(self.data / other[..., np.newaxis])
+
         return NotImplemented
 
     def __rtruediv__(self, other):
@@ -274,22 +270,20 @@ class Vector3d(Object3d):
 
         Returns
         -------
-        Scalar
+        numpy.ndarray
 
         Examples
         --------
         >>> v = Vector3d((0, 0, 1.0))
         >>> w = Vector3d(((0, 0, 0.5), (0.4, 0.6, 0)))
         >>> v.dot(w)
-        Scalar (2,)
-        [ 0.5  0. ]
+        array([0.5, 0.])
         >>> w.dot(v)
-        Scalar (2,)
-        [ 0.5  0. ]
+        array([0.5, 0.])
         """
         if not isinstance(other, Vector3d):
             raise ValueError("{} is not a vector!".format(other))
-        return Scalar(np.sum(self.data * other.data, axis=-1))
+        return np.sum(self.data * other.data, axis=-1)
 
     def dot_outer(self, other):
         """The outer dot product of a vector with another vector.
@@ -299,24 +293,22 @@ class Vector3d(Object3d):
 
         Returns
         -------
-        Scalar
+        numpy.ndarray
 
         Examples
         --------
         >>> v = Vector3d(((0.0, 0.0, 1.0), (1.0, 0.0, 0.0)))  # shape = (2, )
         >>> w = Vector3d(((0.0, 0.0, 0.5), (0.4, 0.6, 0.0), (0.5, 0.5, 0.5)))  # shape = (3, )
         >>> v.dot_outer(w)
-        Scalar (2, 3)
-        [[ 0.5  0.   0.5]
-         [ 0.   0.4  0.5]]
+        array([[ 0.5,  0.,  0.5]
+               [  0., 0.4,  0.5]])
         >>> w.dot_outer(v)  # shape = (3, 2)
-        Scalar (3, 2)
-        [[ 0.5  0. ]
-         [ 0.   0.4]
-         [ 0.5  0.5]]
+        array([[ 0.5,  0. ]
+               [  0.,  0.4]
+               [ 0.5,  0.5]])
         """
         dots = np.tensordot(self.data, other.data, axes=(-1, -1))
-        return Scalar(dots)
+        return dots
 
     def cross(self, other):
         """The cross product of a vector with another vector.
@@ -408,17 +400,17 @@ class Vector3d(Object3d):
 
         Returns
         -------
-        Scalar
+        numpy.ndarray
             The angle between the vectors, in radians.
         """
-        cosines = np.round(self.dot(other).data / self.norm.data / other.norm.data, 12)
-        return Scalar(np.arccos(cosines))
+        cosines = np.round(self.dot(other) / self.norm / other.norm, 12)
+        return np.arccos(cosines)
 
     def rotate(self, axis=None, angle=0):
         """Convenience function for rotating this vector.
 
-        Shapes of 'axis' and 'angle' must be compatible with shape of this
-        vector for broadcasting.
+        Shapes of 'axis' and 'angle' must be compatible with shape of
+        this vector for broadcasting.
 
         Parameters
         ----------
@@ -470,13 +462,13 @@ class Vector3d(Object3d):
         assert self.size == 1, "`get_nearest` only works for single vectors."
         tiebreak = Vector3d.zvector() if tiebreak is None else tiebreak
         eps = 1e-9 if inclusive else 0
-        cosines = x.dot(self).data
+        cosines = x.dot(self)
         mask = np.logical_and(-1 - eps < cosines, cosines < 1 + eps)
         x = x[mask]
         if x.size == 0:
             return Vector3d.empty()
         cosines = cosines[mask]
-        verticality = x.dot(tiebreak).data
+        verticality = x.dot(tiebreak)
         order = np.lexsort((cosines, verticality))
         return x[order[-1]]
 
@@ -492,7 +484,7 @@ class Vector3d(Object3d):
 
         Returns
         -------
-        azimuth, polar, radial : Scalar
+        azimuth, polar, radial : numpy.ndarray
         """
         return self.azimuth, self.polar, self.radial
 
@@ -547,7 +539,7 @@ class Vector3d(Object3d):
             rot = symmetry
 
         rotated_centers = rot * center
-        closeness = v.dot_outer(rotated_centers).data.round(12)
+        closeness = v.dot_outer(rotated_centers).round(12)
         idx_max = np.argmax(closeness, axis=-1)
         v2 = ~rot[idx_max] * v
 
@@ -599,10 +591,12 @@ class Vector3d(Object3d):
         axes_labels=None,
         vector_labels=None,
         hemisphere=None,
+        reproject=False,
         show_hemisphere_label=None,
         grid=None,
         grid_resolution=None,
         figure_kwargs=None,
+        reproject_scatter_kwargs=None,
         text_kwargs=None,
         return_figure=False,
         **kwargs,
@@ -627,6 +621,11 @@ class Vector3d(Object3d):
             otherwise adds to the current figure's hemispheres. Options
             are "upper", "lower", and "both", which plots two
             projections side by side.
+        reproject : bool, optional
+            Whether to reproject vectors onto the chosen hemisphere.
+            Reprojection is achieved by reflection of the vectors
+            located on the opposite hemisphere in the projection plane.
+            Ignored if `hemisphere` is "both". Default is False.
         show_hemisphere_label : bool, optional
             Whether to show hemisphere labels "upper" or "lower".
             Default is True if `hemisphere` is "both", otherwise False.
@@ -641,15 +640,23 @@ class Vector3d(Object3d):
         figure_kwargs : dict, optional
             Dictionary of keyword arguments passed to
             :func:`matplotlib.pyplot.subplots`.
+        reproject_scatter_kwargs: dict, optional
+            Dictionary of keyword arguments for the reprojected scatter
+            points which is passed to
+            :meth:`~orix.plot.StereographicPlot.scatter`, which passes
+            these on to :meth:`matplotlib.axes.Axes.scatter`. The
+            default marker style for reprojected vectors is "+". Values
+            used for vector(s) on the visible hemisphere are used unless
+            another value is passed here.
         text_kwargs : dict, optional
             Dictionary of keyword arguments passed to
-            :func:`~orix.plot.StereographicPlot.text`, which passes
+            :meth:`~orix.plot.StereographicPlot.text`, which passes
             these on to :meth:`matplotlib.axes.Axes.text`.
         return_figure : bool, optional
             Whether to return the figure (default is False).
         kwargs : dict, optional
             Keyword arguments passed to
-            :func:`~orix.plot.StereographicPlot.scatter`, which passes
+            :meth:`~orix.plot.StereographicPlot.scatter`, which passes
             these on to :meth:`matplotlib.axes.Axes.scatter`.
 
         Returns
@@ -669,6 +676,20 @@ class Vector3d(Object3d):
         --------
         orix.plot.StereographicPlot
         """
+        if hemisphere is not None and hemisphere.lower() == "both":
+            reproject = False
+        if reproject:
+            # setup reproject scatter plotting args
+            if reproject_scatter_kwargs is None:
+                reproject_scatter_kwargs = {}
+            reproject_scatter_kwargs.setdefault("marker", "+")
+            # unless otherwise defined, copy normal scatter kwargs
+            for k, v in kwargs.items():
+                if k not in reproject_scatter_kwargs.keys():
+                    reproject_scatter_kwargs[k] = v
+            v_reprojected = deepcopy(self)
+            v_reprojected.z = -v_reprojected.z
+
         (
             fig,
             axes,
@@ -694,6 +715,8 @@ class Vector3d(Object3d):
         for i, ax in enumerate(axes):  # Assumes a maximum of two axes
             ax.hemisphere = hemisphere[i]
             ax.scatter(self, **kwargs)
+            if reproject:
+                ax.scatter(v_reprojected, **reproject_scatter_kwargs)
             ax.stereographic_grid(grid[i], grid_resolution[0], grid_resolution[1])
             ax._stereographic_grid = grid[i]
             ax.set_labels(*axes_labels)
@@ -712,12 +735,14 @@ class Vector3d(Object3d):
         figure=None,
         opening_angle=np.pi / 2,
         steps=100,
+        reproject=False,
         axes_labels=None,
         hemisphere=None,
         show_hemisphere_label=None,
         grid=None,
         grid_resolution=None,
         figure_kwargs=None,
+        reproject_plot_kwargs=None,
         return_figure=False,
         **kwargs,
     ):
@@ -741,6 +766,12 @@ class Vector3d(Object3d):
             its size must be equal to the number of vectors.
         steps : int, optional
             Number of vectors to describe each circle, default is 100.
+        reproject : bool, optional
+            Whether to reproject parts of the circle(s) visible on the
+            other hemisphere. Reprojection is achieved by reflection of
+            the circle(s) parts located on the other hemisphere in the
+            projection plane. Ignored if hemisphere is “both”. Default
+            is False.
         axes_labels : list of str, optional
             Reference frame axes labels, defaults to [None, None, None].
         hemisphere : str, optional
@@ -750,7 +781,7 @@ class Vector3d(Object3d):
             are "upper", "lower", and "both", which plots two
             projections side by side.
         show_hemisphere_label : bool, optional
-            Whether to show hemisphere labels "upper" or "lower".
+            Whether to show hemisphere labels "upper" or "lower`.
             Default is True if `hemisphere` is "both", otherwise False.
         grid : bool, optional
             Whether to show the azimuth and polar grid. Default is
@@ -763,6 +794,13 @@ class Vector3d(Object3d):
         figure_kwargs : dict, optional
             Dictionary of keyword arguments passed to
             :func:`matplotlib.pyplot.subplots`.
+        reproject_plot_kwargs : dict, optional
+            Keyword arguments passed to
+            :meth:`matplotlib.axes.Axes.plot` to alter the appearance of
+            parts of the circle(s) visible on the other hemisphere if
+            `reproject` is True. These lines are dashed by default.
+            Values used for circle(s) on the current hemisphere are used
+            unless values are passed here.
         return_figure : bool, optional
             Whether to return the figure (default is False).
         kwargs
@@ -788,6 +826,16 @@ class Vector3d(Object3d):
         orix.plot.StereographicPlot
         orix.vector.Vector3d.get_circle
         """
+        if hemisphere is not None and hemisphere.lower() == "both":
+            reproject = False
+        if reproject:
+            if reproject_plot_kwargs is None:
+                reproject_plot_kwargs = {}
+            reproject_plot_kwargs.setdefault("linestyle", "--")
+            for k, v in kwargs.items():
+                if k not in reproject_plot_kwargs.keys() and k != "color":
+                    reproject_plot_kwargs[k] = v
+
         (
             fig,
             axes,
@@ -811,7 +859,14 @@ class Vector3d(Object3d):
         # Use methods of the StereographicPlot class
         for i, ax in enumerate(axes):  # Assumes a maximum of two axes
             ax.hemisphere = hemisphere[i]
-            ax.draw_circle(self, opening_angle=opening_angle, steps=steps, **kwargs)
+            ax.draw_circle(
+                self,
+                opening_angle=opening_angle,
+                steps=steps,
+                reproject=reproject,
+                reproject_plot_kwargs=reproject_plot_kwargs,
+                **kwargs,
+            )
             ax.stereographic_grid(grid[i], grid_resolution[0], grid_resolution[1])
             ax._stereographic_grid = grid[i]
             ax.set_labels(*axes_labels)
@@ -880,7 +935,7 @@ class Vector3d(Object3d):
         axes_labels : list
         """
         if projection.lower() != "stereographic":
-            raise NotImplementedError("Stereographic is the only supported projection")
+            raise NotImplementedError("Stereographic is the only supported projection.")
 
         import orix.plot.stereographic_plot
 
